@@ -1,4 +1,4 @@
-/* 
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -18,10 +18,12 @@
  */
 package org.apache.parquet.filter2.predicate;
 
+import static org.apache.parquet.Preconditions.checkArgument;
+
 import java.io.Serializable;
 import java.util.Locale;
 import java.util.Objects;
-
+import java.util.Set;
 import org.apache.parquet.hadoop.metadata.ColumnPath;
 import org.apache.parquet.io.api.Binary;
 
@@ -30,15 +32,17 @@ import org.apache.parquet.io.api.Binary;
  * They are constructed by using the methods in {@link FilterApi}
  */
 public final class Operators {
-  private Operators() { }
+  private Operators() {}
 
-  public static abstract class Column<T extends Comparable<T>> implements Serializable {
+  public abstract static class Column<T extends Comparable<T>> implements Serializable {
     private final ColumnPath columnPath;
     private final Class<T> columnType;
 
     protected Column(ColumnPath columnPath, Class<T> columnType) {
-      this.columnPath = Objects.requireNonNull(columnPath, "columnPath cannot be null");;
-      this.columnType = Objects.requireNonNull(columnType, "columnType cannot be null");;
+      this.columnPath = Objects.requireNonNull(columnPath, "columnPath cannot be null");
+      ;
+      this.columnType = Objects.requireNonNull(columnType, "columnType cannot be null");
+      ;
     }
 
     public Class<T> getColumnType() {
@@ -75,8 +79,10 @@ public final class Operators {
     }
   }
 
-  public static interface SupportsEqNotEq { } // marker for columns that can be used with eq() and notEq()
-  public static interface SupportsLtGt extends SupportsEqNotEq { } // marker for columns that can be used with lt(), ltEq(), gt(), gtEq()
+  public static interface SupportsEqNotEq {} // marker for columns that can be used with eq() and notEq()
+
+  public static interface SupportsLtGt
+      extends SupportsEqNotEq {} // marker for columns that can be used with lt(), ltEq(), gt(), gtEq()
 
   public static final class IntColumn extends Column<Integer> implements SupportsLtGt {
     IntColumn(ColumnPath columnPath) {
@@ -115,10 +121,9 @@ public final class Operators {
   }
 
   // base class for Eq, NotEq, Lt, Gt, LtEq, GtEq
-  static abstract class ColumnFilterPredicate<T extends Comparable<T>> implements FilterPredicate, Serializable  {
+  abstract static class ColumnFilterPredicate<T extends Comparable<T>> implements FilterPredicate, Serializable {
     private final Column<T> column;
     private final T value;
-    private final String toString;
 
     protected ColumnFilterPredicate(Column<T> column, T value) {
       this.column = Objects.requireNonNull(column, "column cannot be null");
@@ -126,9 +131,6 @@ public final class Operators {
       // Eq and NotEq allow value to be null, Lt, Gt, LtEq, GtEq however do not, so they guard against
       // null in their own constructors.
       this.value = value;
-
-      String name = getClass().getSimpleName().toLowerCase(Locale.ENGLISH);
-      this.toString = name + "(" + column.getColumnPath().toDotString() + ", " + value + ")";
     }
 
     public Column<T> getColumn() {
@@ -141,7 +143,8 @@ public final class Operators {
 
     @Override
     public String toString() {
-      return toString;
+      return getClass().getSimpleName().toLowerCase(Locale.ENGLISH) + "("
+          + column.getColumnPath().toDotString() + ", " + value + ")";
     }
 
     @Override
@@ -169,7 +172,7 @@ public final class Operators {
   public static final class Eq<T extends Comparable<T>> extends ColumnFilterPredicate<T> {
 
     // value can be null
-    Eq(Column<T> column, T value) {
+    public Eq(Column<T> column, T value) {
       super(column, value);
     }
 
@@ -177,7 +180,6 @@ public final class Operators {
     public <R> R accept(Visitor<R> visitor) {
       return visitor.visit(this);
     }
-
   }
 
   public static final class NotEq<T extends Comparable<T>> extends ColumnFilterPredicate<T> {
@@ -193,7 +195,6 @@ public final class Operators {
     }
   }
 
-
   public static final class Lt<T extends Comparable<T>> extends ColumnFilterPredicate<T> {
 
     // value cannot be null
@@ -220,7 +221,6 @@ public final class Operators {
     }
   }
 
-
   public static final class Gt<T extends Comparable<T>> extends ColumnFilterPredicate<T> {
 
     // value cannot be null
@@ -247,17 +247,94 @@ public final class Operators {
     }
   }
 
+  /**
+   * Base class for {@link In} and {@link NotIn}. {@link In} is used to filter data based on a list of values.
+   * {@link NotIn} is used to filter data that are not in the list of values.
+   */
+  public abstract static class SetColumnFilterPredicate<T extends Comparable<T>>
+      implements FilterPredicate, Serializable {
+    private final Column<T> column;
+    private final Set<T> values;
+
+    protected SetColumnFilterPredicate(Column<T> column, Set<T> values) {
+      this.column = Objects.requireNonNull(column, "column cannot be null");
+      this.values = Objects.requireNonNull(values, "values cannot be null");
+      checkArgument(!values.isEmpty(), "values in SetColumnFilterPredicate shouldn't be empty!");
+    }
+
+    public Column<T> getColumn() {
+      return column;
+    }
+
+    public Set<T> getValues() {
+      return values;
+    }
+
+    @Override
+    public String toString() {
+      String name = getClass().getSimpleName().toLowerCase(Locale.ENGLISH);
+      StringBuilder str = new StringBuilder();
+      str.append(name)
+          .append("(")
+          .append(column.getColumnPath().toDotString())
+          .append(", ");
+      int iter = 0;
+      for (T value : values) {
+        if (iter >= 100) break;
+        str.append(value).append(", ");
+        iter++;
+      }
+      int length = str.length();
+      str = values.size() <= 100 ? str.delete(length - 2, length) : str.append("...");
+      return str.append(")").toString();
+    }
+
+    @Override
+    public boolean equals(Object o) {
+      if (this == o) return true;
+      if (o == null || getClass() != o.getClass()) return false;
+      SetColumnFilterPredicate<?> that = (SetColumnFilterPredicate<?>) o;
+      return column.equals(that.column) && values.equals(that.values);
+    }
+
+    @Override
+    public int hashCode() {
+      return Objects.hash(column, values);
+    }
+  }
+
+  public static final class In<T extends Comparable<T>> extends SetColumnFilterPredicate<T> {
+
+    public In(Column<T> column, Set<T> values) {
+      super(column, values);
+    }
+
+    @Override
+    public <R> R accept(Visitor<R> visitor) {
+      return visitor.visit(this);
+    }
+  }
+
+  public static final class NotIn<T extends Comparable<T>> extends SetColumnFilterPredicate<T> {
+
+    NotIn(Column<T> column, Set<T> values) {
+      super(column, values);
+    }
+
+    @Override
+    public <R> R accept(Visitor<R> visitor) {
+      return visitor.visit(this);
+    }
+  }
+
   // base class for And, Or
-  private static abstract class BinaryLogicalFilterPredicate implements FilterPredicate, Serializable {
+  private abstract static class BinaryLogicalFilterPredicate implements FilterPredicate, Serializable {
     private final FilterPredicate left;
     private final FilterPredicate right;
-    private final String toString;
 
     protected BinaryLogicalFilterPredicate(FilterPredicate left, FilterPredicate right) {
       this.left = Objects.requireNonNull(left, "left cannot be null");
       this.right = Objects.requireNonNull(right, "right cannot be null");
-      String name = getClass().getSimpleName().toLowerCase(Locale.ENGLISH);
-      this.toString = name + "(" + left + ", " + right + ")";
     }
 
     public FilterPredicate getLeft() {
@@ -270,7 +347,7 @@ public final class Operators {
 
     @Override
     public String toString() {
-      return toString;
+      return getClass().getSimpleName().toLowerCase(Locale.ENGLISH) + "(" + left + ", " + right + ")";
     }
 
     @Override
@@ -321,11 +398,9 @@ public final class Operators {
 
   public static class Not implements FilterPredicate, Serializable {
     private final FilterPredicate predicate;
-    private final String toString;
 
     Not(FilterPredicate predicate) {
       this.predicate = Objects.requireNonNull(predicate, "predicate cannot be null");
-      this.toString = "not(" + predicate + ")";
     }
 
     public FilterPredicate getPredicate() {
@@ -334,7 +409,7 @@ public final class Operators {
 
     @Override
     public String toString() {
-      return toString;
+      return "not(" + predicate + ")";
     }
 
     @Override
@@ -356,7 +431,8 @@ public final class Operators {
     }
   }
 
-  public static abstract class UserDefined<T extends Comparable<T>, U extends UserDefinedPredicate<T>> implements FilterPredicate, Serializable {
+  public abstract static class UserDefined<T extends Comparable<T>, U extends UserDefinedPredicate<T>>
+      implements FilterPredicate, Serializable {
     protected final Column<T> column;
 
     UserDefined(Column<T> column) {
@@ -374,18 +450,16 @@ public final class Operators {
       return visitor.visit(this);
     }
   }
-    
-  public static final class UserDefinedByClass<T extends Comparable<T>, U extends UserDefinedPredicate<T>> extends UserDefined<T, U> {
+
+  public static final class UserDefinedByClass<T extends Comparable<T>, U extends UserDefinedPredicate<T>>
+      extends UserDefined<T, U> {
     private final Class<U> udpClass;
-    private final String toString;
     private static final String INSTANTIATION_ERROR_MESSAGE =
         "Could not instantiate custom filter: %s. User defined predicates must be static classes with a default constructor.";
 
     UserDefinedByClass(Column<T> column, Class<U> udpClass) {
       super(column);
       this.udpClass = Objects.requireNonNull(udpClass, "udpClass cannot be null");
-      String name = getClass().getSimpleName().toLowerCase(Locale.ENGLISH);
-      this.toString = name + "(" + column.getColumnPath().toDotString() + ", " + udpClass.getName() + ")";
 
       // defensively try to instantiate the class early to make sure that it's possible
       getUserDefinedPredicate();
@@ -406,7 +480,8 @@ public final class Operators {
 
     @Override
     public String toString() {
-      return toString;
+      return getClass().getSimpleName().toLowerCase(Locale.ENGLISH) + "("
+          + column.getColumnPath().toDotString() + ", " + udpClass.getName() + ")";
     }
 
     @Override
@@ -430,16 +505,15 @@ public final class Operators {
       return result;
     }
   }
-  
-  public static final class UserDefinedByInstance<T extends Comparable<T>, U extends UserDefinedPredicate<T> & Serializable> extends UserDefined<T, U> {
-    private final String toString;
+
+  public static final class UserDefinedByInstance<
+          T extends Comparable<T>, U extends UserDefinedPredicate<T> & Serializable>
+      extends UserDefined<T, U> {
     private final U udpInstance;
 
     UserDefinedByInstance(Column<T> column, U udpInstance) {
       super(column);
       this.udpInstance = Objects.requireNonNull(udpInstance, "udpInstance cannot be null");
-      String name = getClass().getSimpleName().toLowerCase(Locale.ENGLISH);
-      this.toString = name + "(" + column.getColumnPath().toDotString() + ", " + udpInstance + ")";
     }
 
     @Override
@@ -449,7 +523,8 @@ public final class Operators {
 
     @Override
     public String toString() {
-      return toString;
+      return getClass().getSimpleName().toLowerCase(Locale.ENGLISH) + "("
+          + column.getColumnPath().toDotString() + ", " + udpInstance + ")";
     }
 
     @Override
@@ -476,13 +551,12 @@ public final class Operators {
 
   // Represents the inverse of a UserDefined. It is equivalent to not(userDefined), without the use
   // of the not() operator
-  public static final class LogicalNotUserDefined <T extends Comparable<T>, U extends UserDefinedPredicate<T>> implements FilterPredicate, Serializable {
+  public static final class LogicalNotUserDefined<T extends Comparable<T>, U extends UserDefinedPredicate<T>>
+      implements FilterPredicate, Serializable {
     private final UserDefined<T, U> udp;
-    private final String toString;
 
     LogicalNotUserDefined(UserDefined<T, U> userDefined) {
       this.udp = Objects.requireNonNull(userDefined, "userDefined cannot be null");
-      this.toString = "inverted(" + udp + ")";
     }
 
     public UserDefined<T, U> getUserDefined() {
@@ -496,7 +570,7 @@ public final class Operators {
 
     @Override
     public String toString() {
-      return toString;
+      return "inverted(" + udp + ")";
     }
 
     @Override
@@ -518,5 +592,4 @@ public final class Operators {
       return result;
     }
   }
-
 }
