@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -18,13 +18,8 @@
  */
 package org.apache.parquet.thrift.struct;
 
-
-import java.util.ArrayDeque;
 import java.util.ArrayList;
-import java.util.Deque;
-import java.util.Iterator;
 import java.util.List;
-
 import org.apache.parquet.thrift.projection.FieldsPath;
 import org.apache.parquet.thrift.struct.ThriftType.BoolType;
 import org.apache.parquet.thrift.struct.ThriftType.ByteType;
@@ -46,10 +41,9 @@ public class CompatibilityChecker {
 
   public CompatibilityReport checkCompatibility(ThriftType.StructType oldStruct, ThriftType.StructType newStruct) {
     CompatibleCheckerVisitor visitor = new CompatibleCheckerVisitor();
-    newStruct.accept(visitor, new State(oldStruct,new FieldsPath()));
+    newStruct.accept(visitor, new State(oldStruct, new FieldsPath()));
     return visitor.getReport();
   }
-
 }
 
 class CompatibilityReport {
@@ -85,11 +79,10 @@ class CompatibilityReport {
 
   @Override
   public String toString() {
-    return "CompatibilityReport{" +
-        "isCompatible=" + isCompatible +
-        ", hasEmptyStruct=" + hasEmptyStruct +
-        ", messages=\n" + prettyMessages() +
-        '}';
+    return "CompatibilityReport{" + "isCompatible="
+        + isCompatible + ", hasEmptyStruct="
+        + hasEmptyStruct + ", messages=\n"
+        + prettyMessages() + '}';
   }
 }
 
@@ -120,7 +113,6 @@ class CompatibleCheckerVisitor implements ThriftType.StateVisitor<Void, State> {
     ThriftField newValueField = mapType.getValue();
     ThriftField oldValueField = oldMapType.getValue();
 
-
     checkField(oldKeyField, newKeyField, state.path);
     checkField(oldValueField, newValueField, state.path);
 
@@ -146,13 +138,16 @@ class CompatibleCheckerVisitor implements ThriftType.StateVisitor<Void, State> {
   }
 
   public void incompatible(String message, FieldsPath path) {
-    report.fail("at " + path + ":" +message);
+    report.fail("at " + path + ":" + message);
   }
 
   private void checkField(ThriftField oldField, ThriftField newField, FieldsPath path) {
 
     if (!newField.getType().getType().equals(oldField.getType().getType())) {
-      incompatible("type is not compatible: " + oldField.getType().getType() + " vs " + newField.getType().getType(), path);
+      incompatible(
+          "type is not compatible: " + oldField.getType().getType() + " vs "
+              + newField.getType().getType(),
+          path);
       return;
     }
 
@@ -166,7 +161,7 @@ class CompatibleCheckerVisitor implements ThriftType.StateVisitor<Void, State> {
       return;
     }
 
-    newField.getType().accept(this, new State(oldField.getType(),path.push(newField)));
+    newField.getType().accept(this, new State(oldField.getType(), path.push(newField)));
   }
 
   private boolean firstIsMoreRestirctive(ThriftField.Requirement firstReq, ThriftField.Requirement secReq) {
@@ -175,7 +170,6 @@ class CompatibleCheckerVisitor implements ThriftType.StateVisitor<Void, State> {
     } else {
       return false;
     }
-
   }
 
   @Override
@@ -200,11 +194,10 @@ class CompatibleCheckerVisitor implements ThriftType.StateVisitor<Void, State> {
       checkField(oldField, newField, state.path);
     }
 
-    //check for new added
+    // check for new added
     for (ThriftField newField : newStruct.getChildren()) {
-      //can not add required
-      if (newField.getRequirement() != ThriftField.Requirement.REQUIRED)
-        continue;//can add optional field
+      // can not add required
+      if (newField.getRequirement() != ThriftField.Requirement.REQUIRED) continue; // can add optional field
 
       short newFieldId = newField.getFieldId();
       if (newFieldId > oldMaxId) {
@@ -215,7 +208,6 @@ class CompatibleCheckerVisitor implements ThriftType.StateVisitor<Void, State> {
         incompatible("new required field " + newField.getName() + " is added", state.path);
         return null;
       }
-
     }
 
     return null;
@@ -260,6 +252,9 @@ class CompatibleCheckerVisitor implements ThriftType.StateVisitor<Void, State> {
   public Void visit(StringType stringType, State state) {
     return null;
   }
+
+  @Override
+  public Void visit(ThriftType.UUIDType uuidType, State state) {
+    return null;
+  }
 }
-
-
